SquidMesh.Persistence.StepAttempt (squid_mesh v0.1.0-alpha.3)

Copy Markdown View Source

Persisted attempt state for a step run.

Step attempts capture retry history independently from the latest step state so the runtime can record how many times a step was attempted and what error payload was produced for each attempt.

Summary

Functions

Builds a changeset for persisted step attempt state.

Types

status()

@type status() :: String.t()

t()

@type t() :: %SquidMesh.Persistence.StepAttempt{
  __meta__: term(),
  attempt_number: term(),
  error: term(),
  id: term(),
  inserted_at: term(),
  status: term(),
  step_run: term(),
  step_run_id: term(),
  updated_at: term()
}

Functions

changeset(step_attempt, attrs)

@spec changeset(t(), map()) :: Ecto.Changeset.t()

Builds a changeset for persisted step attempt state.