Persisted state for one workflow step execution.
A step run belongs to a workflow run and tracks the step input, output, and latest error payload for that step within the durable execution history.
Summary
Functions
Builds a changeset for persisted step run state.
Types
@type status() :: String.t()
Functions
@spec changeset(t(), map()) :: Ecto.Changeset.t()
Builds a changeset for persisted step run state.