Persisted attempt state for a step run.
Step attempts capture retry history independently from the latest step state so the runtime can record how many times a step was attempted and what error payload was produced for each attempt.
Summary
Functions
Builds a changeset for persisted step attempt state.
Types
Functions
@spec changeset(t(), map()) :: Ecto.Changeset.t()
Builds a changeset for persisted step attempt state.