Executes one workflow step through Jido and persists the outcome.
This module is the runtime boundary where declarative workflow definitions are turned into durable step execution and persisted run progress.
Summary
Types
@type execution_error() :: :not_found | {:invalid_workflow, module() | String.t()} | {:invalid_step, atom() | String.t() | nil} | {:dispatch_failed, term()} | {:invalid_run, Ecto.Changeset.t()} | {:invalid_transition, SquidMesh.Run.status(), SquidMesh.Run.status()} | {:unknown_transition, atom(), atom()} | {:unknown_step, atom()} | {:missing_config, [atom()]}
Functions
@spec execute(Ecto.UUID.t(), expected_step(), keyword()) :: :ok | {:error, execution_error() | term()}