Normalized tool failure shape.
Summary
Functions
Builds a normalized tool error.
Converts a tool error into a plain map suitable for step error payloads.
Normalized tool failure shape.
Builds a normalized tool error.
Converts a tool error into a plain map suitable for step error payloads.